---
# vim:tw=100:ft=markdown
author: <white><small>Sander Apweiler, Marcus Hardt, Uwe Jandt, Andreas Klotz</small></white>
title: <white><br/><br/><small> Helmholtz-AAI </small></white>
date: <white>October 2021</white>
theme: marcus
parallaxBackgroundImage: images/helmholtz-bg-slide.png
title-slide-attributes:
    data-background-image: images/helmholtz-bg-head.png
slideNumber: \'c/t\'
preloadIframes: true
showNotes: false
mouseWheel: true
transition: none
backgroundTransition: none
---
## Presentation Metadata:
- Tag 1, 26. Oktober 2021
- 11:15-12:15 Uhr
- Agenda hier: [https://www.dfn.de/veranstaltungen/betriebstagungen/infos](https://www.dfn.de/veranstaltungen/betriebstagungen/infos) (bald)


## Outline
- Motivation
- Architecture
- Implementation
- Developments


# Motivation <br/> + <br/> Overview
## Historical records
- Helmholtz Data Federation (HDF) needed an AAI
- Proof of Concept implementation of the [AARC Blueprint Architecture](https://aarc-community.org/architecture)
    - SP-IdP Proxy (in eduGain)
    - 4 Initial services (Nagios, OpenStack, DCache, WaTTS, ...)
    - OpenID Connect as a primary target
- Adaptation of the [AARC Policy Development Kit](https://aarc-community.org/policies/policy-development-kit)
    - Security + Trust
    - Policy Compatibility with large infrastructures (WLCG, LIGO, XSEDE, ELIXIR, ...)

<none class="fragment"data-fragment-index="2"> Then HIFIS started


## {data-background-image="images/motivation1b.png" data-background-size="fill"}
## {data-background-image="images/motivation2b.png" data-background-size="fill"}
## {data-background-image="images/motivation3b.png" data-background-size="fill"}


## Helmholtz AAI: Goals
- Users can access **many** federated services
    - with the **one account** of their Home Organisation
- Seamless access
    - Enable Services for users at Helmholtz Centres and Partners
    - Enable researchers and guests to access Services
    - Very general approach => Don't be limited by specific organisational structure
- Enable PIs to manage their own Virtual Organisations (VOs)
- Compatibility with the European Open Science Cloud (EOSC)
- Support for services beyond the browser
    - Delegation (Computing Jobs)
    - REST APIs
    - Shell access


## Relation to DFN-AAI
- Overlap only in the acronym "AAI"
- Helmholtz AAI is _one_ service inside DFN-AAI
    - it's an SP-IdP-proxy
- Users come in via 
    - **DFN-AAI**, eduGAIN, 
    - And others: ORCID, Github, Google
    - Even "Homeless Users" __could__ be supported


## {data-background-image="images/foederationen_und_bpa.png" data-background-size="contain"}


# Architecture
## AARC
- [Authentication and Authorisation for Research Communities (AARC)](https://aarc-project.eu)
    - 25 Partners 
    - 4 Years
- Mission
    - Analyse **existing** Architectures
    - Analyse **existing** Policies
    - => Give recommendations 
        - 21 Final, ~15 more on the roadmap


## AARC Results
- [AARC Blueprint Architectures](https://aarc-community.org/architecture/) 
    - Introduction of the "proxy" component
- [AARC Policy Development KIT](https://aarc-community.org/policies/policy-development-kit/)
    - Fundamental policy templates for
        - Operating an infrastructure
        - Handling Incident Response
        - Manage Members
        - Requirements on Authentication
        - Risk Assessment
        - Data Protection
        - Privacy Policy
        - Service Operation
        - Acceptable Use Policy

         All policies designed to be GDPR compliant


## The **"proxy"** component
aka: "SP-IdP-Proxy"

- Scalability!
    - Stop every IdP needing to talk to every SP (`2800 * 1800`)
    - Reliable Attribute release 
        - (Different nations, different IdPs, each with different schema)
- Third party **authorisation**
    - *"Community Attribute Services"*
- Enforcement of authorisation
- Protocol Translation
    - SAML, OIDC, X.509
- Stackable


## {data-background-image="images/bpa-final-glow.png" data-background-size="contain"}


## Evolution of the BPA (~2019)
- Add differentiation:
    - Between **community** and **infrastructure**
    - Between "infrastructure run by a community" and "general e-Infrastructure"
    - Different types of Services
- Introduces the vocabulary used 
- Full Document: <small>[https://zenodo.org/record/3672785/files/AARC-G045-AARC_BPA_2019-Final.pdf](https://zenodo.org/record/3672785/files/AARC-G045-AARC_BPA_2019-Final.pdf)</small>

## {data-background-image="images/bpa2019.png" data-background-size="contain"}


# Implementation


## Connected Services
- Multi Protocol:
    - Identities: SAML, OpenID Connect, X.509
    - Services: OpenID Connect, SAML
- Integrated Services:
  - Gitlab, Sync&Share, Chat, Storage, Compute & more.
  - High level overview (a.k.a. Helmholtz Cloud Services): [cloud.helmholtz.de/services](https://cloud.helmholtz.de/services)
  - More pilot services at [documentation pages](https://hifis.net/doc/cloud-services/list-of-services/#pilot-services)
  - Exhaustive list: [aai.helmholtz.de/services](https://aai.helmholtz.de/services)
- Helmholtz Federated IT services (HIFIS, [hifis.net](https://hifis.net))
  - Drives development, documentation and service integration

## **Helmholtz-AAI** <br/>implements<br/> **AARC BPA**
## Technical implementation
- Software: `unity`
    - Production: [https://login.helmholtz.de](https://login.helmholtz.de)
    - Development: [https://login-dev.helmholtz.de](https://login-dev.helmholtz.de)
- Self service Group Membership:
    - Principal Investigators can request a group
    - Manage their members


## Helmholtz-AAI Features
- Follows AARC recommendations (a lot of the `G0XY` documents)
    - <=> To use specific schemas for attributes and their content
- Focused on OIDC
- Implements the [Policy Development Kit](https://aarc-community.org/policies/policy-development-kit)
- Explicit Assurance
- Well Documented
- URN registries for 
    - `G002` (Soon: `G059`) style group memberships
    - `G027` style resource capabilities
- HIFIS is an (observing) member of AEGIS



## Authorisation Management<br/>Based on **Community**
- **Virtual Organisation (VO)** approach
- Very similar: HPC compute projects
- **VO** Managers can administer community members
- Services can filter users by
    - VO Attributes
        - `climate -> ozone -> south-pole`
        - `cern -> cms -> admin`


## Authorisation Management<br/>Based on **Origin**
- **Home-IdP based** approach
- Home IdP can assert complementary information
- Services can filter users by
    - Home-Org asserted eligibility to use certain resources
    - Status: - Employee / Student / Guest


## Authorisation Management<br/>Based on **Assurance**
- Levels of Assurance: [REFEDS Assurance Framework](https://refeds.org/assurance)
    - Passport seen, Work-Contract available (Most academic Institutes)
    - Uniqueness of the identifier
    - Freshness of attributes
    - Verified Email Address (Social Media)
- Benefit
    - AAI can host "lesser-than-maximum" users
    - Scientists only need to upgrade their identity, if necessary to access service
    - Services can provide different levels of access


## AAI usage
<img src="images/aai-usage-plot.png" width=85%>


## <small>Further documentation</small>
- See further documentation:
  - <https://aai.helmholtz.de/doc>
  - <https://hifis.net/doc>




# AAI Developments in Helmholtz
## Developments
- Local-agent
- oidc on the commandline
    - oidc-agent
    - mytoken
- ssh/oidc with federated identities


# Backupslides
## Not to forget:
- Helmholtz-AAI is free of charge (at least for Helmholtz)


----------------------------------------------------------------------------------------


## {data-background-image="images/h-aai-konrad.png" data-background-size="fill"}

# Usage Figures {data-background-image="images/hdf-aai-over-time.png" data-background-size="contain" data-transition="zoom"}
## {data-background-image="images/hdf-aai-over-time.png" data-background-size="contain"}


## More information

[https://aai.helmholtz.de](https://aai.helmholtz.de)

